/**
 * Sample React Native App
 * https://github.com/facebook/react-native
 *
 * Generated with the TypeScript template
 * https://github.com/react-native-community/react-native-template-typescript
 *
 * @format
 */

import React from 'react';

import {
  SafeAreaView,
  ScrollView,
  StatusBar,
  StyleSheet,
  Text,
  useColorScheme,
  View,
  Button,
} from 'react-native';

import {
  Colors,
  DebugInstructions,
  Header,
  LearnMoreLinks,
} from 'react-native/Libraries/NewAppScreen';

import {
  initDY,
  trackEvent,
  sendPageView,
  consentOptOut,
  consentOptIn,
  setEvaluator,
  getSmartObjectData,
  getSmartVariable,
  identifyUser,
  setUseEuropeanServer,
  sendRecommendationRequest,
  trackRecomItemRealImpression,
  trackRecomItemClick,
} from './DYModule';

const App = () => {
  const isDarkMode = useColorScheme() === 'dark';

  const backgroundStyle = {
    backgroundColor: isDarkMode ? Colors.darker : Colors.lighter,
  };

  return (
    <SafeAreaView style={backgroundStyle}>
      <StatusBar barStyle={isDarkMode ? 'light-content' : 'dark-content'} />
      <ScrollView
        contentInsetAdjustmentBehavior="automatic"
        style={backgroundStyle}>
        <Header />
        <View
          style={{
            backgroundColor: isDarkMode ? Colors.black : Colors.white,
          }}>
          <Section title="Step One">Init DY with your secret key</Section>
          <Button onPress={initDY} title="initDY" />
          <Section title="Step Two">Send Events</Section>
          <Button onPress={sendPageView} title="sendPageView" />
          <Section title="Step Three">Send Page View</Section>
          <Button onPress={trackEvent} title="trackEvent" />
          <Section title="Consent">Enable/Disable Consent</Section>
          <Button onPress={consentOptIn} title="consentOptIn" />
          <Button onPress={consentOptOut} title="consentOptOut" />
          <Section title="Evaluator">Set evaluator value</Section>
          <Button onPress={setEvaluator} title="setEvaluator" />

          <Section title="SmartObjectData">Get SmartObject Data</Section>
          <Button onPress={getSmartObjectData} title="getSmartObjectData" />

          <Section title="getSmartVariable">Get SmartVariable Value</Section>
          <Button onPress={getSmartVariable} title="getSmartVariable" />

          <Section title="identifyUser">Send identifyUser</Section>
          <Button onPress={identifyUser} title="identifyUser" />

          <Section title="setUseEuropeanServer">
            Set Use European Server True/False
          </Section>
          <Button onPress={setUseEuropeanServer} title="setUseEuropeanServer" />

          <Section title="setUseEuropeanServer">
            Set Use European Server True/False
          </Section>
          <Button onPress={setUseEuropeanServer} title="setUseEuropeanServer" />

          <Section title="Recommendations">
            sendRecommendationRequest - request Recommendations;
            trackRecomItemRealImpression - track Real impressions on
            recommendation item; trackRecomItemClick - track clicked on
            recommendation item
          </Section>
          <Button
            onPress={sendRecommendationRequest}
            title="sendRecommendationRequest"
          />
          <Button
            onPress={trackRecomItemRealImpression}
            title="trackRecomItemRealImpression"
          />
          <Button onPress={trackRecomItemClick} title="trackRecomItemClick" />
        </View>
      </ScrollView>
    </SafeAreaView>
  );
};

const Section: React.FC<{
  title: string;
}> = ({children, title}) => {
  const isDarkMode = useColorScheme() === 'dark';
  return (
    <View style={styles.sectionContainer}>
      <Text
        style={[
          styles.sectionTitle,
          {
            color: isDarkMode ? Colors.white : Colors.black,
          },
        ]}>
        {title}
      </Text>
      <Text
        style={[
          styles.sectionDescription,
          {
            color: isDarkMode ? Colors.light : Colors.dark,
          },
        ]}>
        {children}
      </Text>
    </View>
  );
};

const styles = StyleSheet.create({
  sectionContainer: {
    marginTop: 32,
    paddingHorizontal: 24,
  },
  sectionTitle: {
    fontSize: 24,
    fontWeight: '600',
  },
  sectionDescription: {
    marginTop: 8,
    fontSize: 18,
    fontWeight: '400',
  },
  highlight: {
    fontWeight: '700',
  },
});

export default App;
